"use strict";var o=function(r,t){return function(){return t||r((t={exports:{}}).exports,t),t.exports}};var i=o(function(p,e){
var s=require('@stdlib/utils-get-prototype-of/dist'),n=require('@stdlib/utils-native-class/dist');function f(r){if(typeof r!="object"||r===null)return!1;if(r instanceof Error)return!0;for(;r;){if(n(r)==="[object Error]")return!0;r=s(r)}return!1}e.exports=f
});var u=i();module.exports=u;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
